import os

from flask import jsonify, Response
from flask_restx import Resource, Namespace

from app.defines import StatesCode
from app.utils.jwt_util import login_required
from config import Config

ns = Namespace('download', description='文件下载接口')

config = Config()


@ns.route('/<file_name>')
class DownloadFileApi(Resource):
    method_decorators = [login_required]

    @ns.doc(description='文件下载')
    def get(self, file_name):
        """文件下载"""

        file_path = os.path.join(config.common.SAVE_FILE_PATH, file_name)

        if not os.path.exists(file_path):
            return jsonify(code=StatesCode.UNKNOWN_ERROR, message='文件%s不存在' % file_name)

        with open(file_path, 'rb') as f:
            data = f.read()

        response = Response(data)
        response.headers['Content-Type'] = 'application/octet-stream'
        response.headers['Content-Disposition'] = 'attachment; filename=%s' % file_name

        return response
